## Versions

0.0.1 - initial build
0.0.2 - changed package name to currencych
0.0.3 - debugging, changed back to currency-ch
0.0.4 - fixed upload
0.0.5 - fixed circular import
0.0.6 - fixed circular import
0.0.7 - fixed local path for currency.csv
0.0.8 - added trailing zeroes and fixed rounding
0.0.9 - fixed concat issue from 0.0.8
0.1.0 - added currency.add()